/hg/gfx-test: Updated several tests.

ptisnovs at icedtea.classpath.org ptisnovs at icedtea.classpath.org
Thu Aug 13 08:20:46 UTC 2015


changeset a55ded659895 in /hg/gfx-test
details: http://icedtea.classpath.org/hg/gfx-test?cmd=changeset;node=a55ded659895
author: Pavel Tisnovsky <ptisnovs at redhat.com>
date: Thu Aug 13 10:23:30 2015 +0200

	Updated several tests.


diffstat:

 ChangeLog                                          |    7 +-
 src/org/gfxtest/testsuites/BitBltUsingBgColor.java |  128 ++++++++++----------
 2 files changed, 70 insertions(+), 65 deletions(-)

diffs (215 lines):

diff -r d75f7a3cfe3e -r a55ded659895 ChangeLog
--- a/ChangeLog	Wed Aug 12 11:01:53 2015 +0200
+++ b/ChangeLog	Thu Aug 13 10:23:30 2015 +0200
@@ -1,4 +1,9 @@
-2015-08-11  Pavel Tisnovsky  <ptisnovs at redhat.com>
+2015-08-13  Pavel Tisnovsky  <ptisnovs at redhat.com>
+
+	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
+	Updated several tests.
+
+2015-08-12  Pavel Tisnovsky  <ptisnovs at redhat.com>
 
 	* src/org/gfxtest/testsuites/BitBltUsingBgColor.java:
 	New tests added into BitBltUsingBgColor.
diff -r d75f7a3cfe3e -r a55ded659895 src/org/gfxtest/testsuites/BitBltUsingBgColor.java
--- a/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Wed Aug 12 11:01:53 2015 +0200
+++ b/src/org/gfxtest/testsuites/BitBltUsingBgColor.java	Thu Aug 13 10:23:30 2015 +0200
@@ -10006,7 +10006,7 @@
     }
 
     /**
      * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10015,13 +10015,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10030,13 +10030,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundCyan(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.cyan);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundCyan(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.cyan);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.red.
      *
      * @param image
@@ -10045,13 +10045,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundRed(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.red);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundRed(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.red);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.magenta.
      *
      * @param image
@@ -10060,13 +10060,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundMagenta(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.magenta);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundMagenta(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.magenta);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.yellow.
      *
      * @param image
@@ -10075,13 +10075,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundYellow(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.yellow);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundYellow(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.yellow);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.white.
      *
      * @param image
@@ -10090,13 +10090,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshort565RGBBackgroundWhite(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshort565RGB(image, graphics2d, Color.white);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntRGBbackgroundWhite(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntRGB(image, graphics2d, Color.white);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.black.
      *
      * @param image
@@ -10105,13 +10105,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlack(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.black);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlack(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.black);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.blue.
      *
      * @param image
@@ -10120,13 +10120,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundBlue(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.blue);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundBlue(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.blue);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.green.
      *
      * @param image
@@ -10135,13 +10135,13 @@
      *            graphics canvas
      * @return test result status - PASSED, FAILED or ERROR
      */
-    public TestResult testBitBltEmptyBufferedImageTypeUshortGrayBackgroundGreen(TestImage image, Graphics2D graphics2d)
-    {
-        return doBitBltEmptyBufferedImageTypeUshortGray(image, graphics2d, Color.green);
-    }
-
-    /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_BYTE_GRAY.
+    public TestResult testBitBltCheckerBufferedImageTypeIntARGBbackgroundGreen(TestImage image, Graphics2D graphics2d)
+    {
+        return doBitBltCheckerBufferedImageTypeIntARGB(image, graphics2d, Color.green);
+    }
+
+    /**
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_ARGB}.
      * Background color is set to Color.cyan.
      *
      * @param image
@@ -10006,7 +10006,7 @@
 
     /**
-     * Test basic BitBlt operation for empty buffered image with type TYPE_USHORT_565_RGB.
+     * Test basic BitBlt operation for checker buffered image with type {@link BufferedImage#TYPE_INT_RGB}.
      * Background color is set to Color.green.
      *


More information about the distro-pkg-dev mailing list